@@ -3,8 +3,8 @@ package Catalyst::Devel;
 use strict;
 use warnings;
 
-our $VERSION             = '1.07';
-our $CATALYST_SCRIPT_GEN = 31;
+our $VERSION             = '1.09';
+our $CATALYST_SCRIPT_GEN = 32;
 
 =head1 NAME
 
@@ -29,7 +29,11 @@ L<Catalyst|Catalyst::Runtime>.
 
 =head1 AUTHOR
 
-The Catalyst Core Team - see http://catalyst.perl.org/
+Catalyst Contributors, see Catalyst.pm
+
+=head1 PROJECT FOUNDER
+
+sri: Sebastian Riedel <sri@cpan.org>
 
 =head1 LICENSE
 
